==> apache-asterixdb-0.9.4-source-release.zip: apache-asterixdb-0.9.4/asterix-common/src/main/java/org/apache/asterix/common/api/ICoordinationService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.api;

import java.util.Optional;

import org.apache.hyracks.api.exceptions.HyracksDataException;

public interface ICoordinationService {

    /**
     * Adds or updates the property with the name {@code key}
     * with {@code value}
     *
     * @param key
     * @param value
     * @throws HyracksDataException
     */
    void put(String key, byte[] value) throws HyracksDataException;

    /**
     * Gets the value of the property with name {@code key} if exists.
     *
     * @param key
     * @return optional with the value or {@link Optional#empty()}
     * @throws HyracksDataException
     */
    Optional<byte[]> get(String key) throws HyracksDataException;

    /**
     * Deletes the property with name {@code key} if exists.
     *
     * @param key
     * @throws HyracksDataException
     */
    void delete(String key) throws HyracksDataException;
}

==> apache-asterixdb-0.9.7.1-source-release.zip: apache-asterixdb-0.9.7.1/asterix-common/src/main/java/org/apache/asterix/common/api/ICoordinationService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.api;

import java.util.Optional;

import org.apache.hyracks.api.exceptions.HyracksDataException;

public interface ICoordinationService {

    /**
     * Adds or updates the property with the name {@code key}
     * with {@code value}
     *
     * @param key
     * @param value
     * @throws HyracksDataException
     */
    void put(String key, byte[] value) throws HyracksDataException;

    /**
     * Adds or updates the property with the name {@code key}
     * with {@code value}, and indicates that values associated with
     * this key should be treated as sensitive (e.g. not logged). Once a
     * key is considered sensitive, it remains sensitive until deleted.
     *
     * @param key
     * @param value
     * @throws HyracksDataException
     */
    void putSensitive(String key, byte[] value) throws HyracksDataException;

    /**
     * Gets the value of the property with name {@code key} if exists.
     *
     * @param key
     * @return optional with the value or {@link Optional#empty()}
     * @throws HyracksDataException
     */
    Optional<byte[]> get(String key) throws HyracksDataException;

    /**
     * Deletes the property with name {@code key} if exists.
     *
     * @param key
     * @throws HyracksDataException
     */
    void delete(String key) throws HyracksDataException;
}
